==> openshift-model-operatorhub-5.12.4-sources.jar: io/fabric8/openshift/api/model/operatorhub/lifecyclemanager/v1/PackageManifestStatusBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PackageManifestStatusBuilder extends io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifestStatusFluentImpl<io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifestStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifestStatus,io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifestStatusBuilder>{
  public PackageManifestStatusBuilder() {
    this(false);
  }
  public PackageManifestStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new PackageManifestStatus(), validationEnabled);
  }
  public PackageManifestStatusBuilder(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifestStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public PackageManifestStatusBuilder(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifestStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PackageManifestStatus(), validationEnabled);
  }
  public PackageManifestStatusBuilder(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifestStatusFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifestStatus instance) {
    this(fluent, instance, false);
  }
  public PackageManifestStatusBuilder(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifestStatusFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifestStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCatalogSource(instance.getCatalogSource()); 
    fluent.withCatalogSourceDisplayName(instance.getCatalogSourceDisplayName()); 
    fluent.withCatalogSourceNamespace(instance.getCatalogSourceNamespace()); 
    fluent.withCatalogSourcePublisher(instance.getCatalogSourcePublisher()); 
    fluent.withChannels(instance.getChannels()); 
    fluent.withDefaultChannel(instance.getDefaultChannel()); 
    fluent.withPackageName(instance.getPackageName()); 
    fluent.withProvider(instance.getProvider()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PackageManifestStatusBuilder(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifestStatus instance) {
    this(instance,false);
  }
  public PackageManifestStatusBuilder(io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifestStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withCatalogSource(instance.getCatalogSource()); 
    this.withCatalogSourceDisplayName(instance.getCatalogSourceDisplayName()); 
    this.withCatalogSourceNamespace(instance.getCatalogSourceNamespace()); 
    this.withCatalogSourcePublisher(instance.getCatalogSourcePublisher()); 
    this.withChannels(instance.getChannels()); 
    this.withDefaultChannel(instance.getDefaultChannel()); 
    this.withPackageName(instance.getPackageName()); 
    this.withProvider(instance.getProvider()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifestStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1.PackageManifestStatus build() {
    PackageManifestStatus buildable = new PackageManifestStatus(fluent.getCatalogSource(),fluent.getCatalogSourceDisplayName(),fluent.getCatalogSourceNamespace(),fluent.getCatalogSourcePublisher(),fluent.getChannels(),fluent.getDefaultChannel(),fluent.getPackageName(),fluent.getProvider());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PackageManifestStatusBuilder that = (PackageManifestStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-6.6.2-sources.jar: io/fabric8/openshift/api/model/operatorhub/lifecyclemanager/v1/PackageManifestStatusBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.lifecyclemanager.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PackageManifestStatusBuilder extends PackageManifestStatusFluentImpl<PackageManifestStatusBuilder> implements VisitableBuilder<PackageManifestStatus,PackageManifestStatusBuilder>{
  public PackageManifestStatusBuilder() {
    this(false);
  }
  public PackageManifestStatusBuilder(Boolean validationEnabled) {
    this(new PackageManifestStatus(), validationEnabled);
  }
  public PackageManifestStatusBuilder(PackageManifestStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public PackageManifestStatusBuilder(PackageManifestStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PackageManifestStatus(), validationEnabled);
  }
  public PackageManifestStatusBuilder(PackageManifestStatusFluent<?> fluent,PackageManifestStatus instance) {
    this(fluent, instance, false);
  }
  public PackageManifestStatusBuilder(PackageManifestStatusFluent<?> fluent,PackageManifestStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCatalogSource(instance.getCatalogSource()); 
    fluent.withCatalogSourceDisplayName(instance.getCatalogSourceDisplayName()); 
    fluent.withCatalogSourceNamespace(instance.getCatalogSourceNamespace()); 
    fluent.withCatalogSourcePublisher(instance.getCatalogSourcePublisher()); 
    fluent.withChannels(instance.getChannels()); 
    fluent.withDefaultChannel(instance.getDefaultChannel()); 
    fluent.withPackageName(instance.getPackageName()); 
    fluent.withProvider(instance.getProvider()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PackageManifestStatusBuilder(PackageManifestStatus instance) {
    this(instance,false);
  }
  public PackageManifestStatusBuilder(PackageManifestStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withCatalogSource(instance.getCatalogSource()); 
    this.withCatalogSourceDisplayName(instance.getCatalogSourceDisplayName()); 
    this.withCatalogSourceNamespace(instance.getCatalogSourceNamespace()); 
    this.withCatalogSourcePublisher(instance.getCatalogSourcePublisher()); 
    this.withChannels(instance.getChannels()); 
    this.withDefaultChannel(instance.getDefaultChannel()); 
    this.withPackageName(instance.getPackageName()); 
    this.withProvider(instance.getProvider()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  PackageManifestStatusFluent<?> fluent;
  Boolean validationEnabled;
  public PackageManifestStatus build() {
    PackageManifestStatus buildable = new PackageManifestStatus(fluent.getCatalogSource(),fluent.getCatalogSourceDisplayName(),fluent.getCatalogSourceNamespace(),fluent.getCatalogSourcePublisher(),fluent.getChannels(),fluent.getDefaultChannel(),fluent.getPackageName(),fluent.getProvider());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
